@@ -1,5 +1,12 @@
 from flask.ext.admin import Admin
-from flask import Blueprint
+from flask import Blueprint, render_template
+
+from flask.ext.admin.base import expose, AdminIndexView
+
+class ShelfIndexView(AdminIndexView):
+    @expose('/login/')
+    def login(self):
+        return render_template("shelf-admin/login.html")
 
 class ShelfAdmin(Admin):
     def __init__(self, app=None, name=None,
@@ -11,6 +18,8 @@ class ShelfAdmin(Admin):
                  base_template=None):
         if base_template is None:
             base_template = "shelf-admin/base.html"
+        if index_view is None:
+            index_view = ShelfIndexView(endpoint=endpoint, url=url)
         super(ShelfAdmin, self).__init__(app, name, url, subdomain, 
             index_view, translations_path, 
             endpoint, static_url_path, base_template)
@@ -20,3 +29,5 @@ class ShelfAdmin(Admin):
         shelf_admin = Blueprint('shelf', 'shelf', url_prefix="/shelf", 
             template_folder="templates", static_folder="static")
         self.app.register_blueprint(shelf_admin)
+    
+    
\ No newline at end of file
