@@ -11,6 +11,8 @@ from operator import itemgetter
 from flask import request, url_for
 from sqlalchemy.types import Text
 
+from sqlalchemy.sql.expression import desc
+
 from base64 import b64decode
 
 from jinja2 import contextfunction
@@ -37,6 +39,89 @@ class ShelfModelView(sqla.ModelView):
     create_template = "shelf-admin/model/create.html"
     edit_template = "shelf-admin/model/edit.html"
 
+    def _order_by(self, query, joins, sort_field, sort_desc):
+        """
+            Apply order_by to the query
+
+            :param query:
+                Query
+            :param joins:
+                Joins set
+            :param sort_field:
+                Sort field
+            :param sort_desc:
+                Ascending or descending
+        """
+
+        try:
+            if issubclass(sort_field.mapper.class_, shelf_computed_models()['LocalizedString']):
+                table = sort_field.mapper.tables[0]
+
+                query = query.outerjoin(str(sort_field).split('.')[1])
+                joins.add(table.name)
+
+                if sort_desc:
+                    query = query.order_by(desc(shelf_computed_models()['LocalizedString'].value))
+                else:
+                    query = query.order_by(shelf_computed_models()['LocalizedString'].value)
+
+                return query, joins
+        except:
+            pass
+
+        try:
+            if issubclass(sort_field.mapper.class_, shelf_computed_models()['RemoteFile']):
+                table = sort_field.mapper.tables[0]
+
+                query = query.outerjoin(str(sort_field).split('.')[1])
+                joins.add(table.name)
+
+                if sort_desc:
+                    query = query.order_by(desc(shelf_computed_models()['RemoteFile'].path))
+                else:
+                    query = query.order_by(shelf_computed_models()['RemoteFile'].path)
+
+                return query, joins
+        except:
+            pass
+
+        try:
+            if issubclass(sort_field.mapper.class_, shelf_computed_models()['Picture']):
+                table = sort_field.mapper.tables[0]
+
+                query = query.outerjoin(str(sort_field).split('.')[1])
+                joins.add(table.name)
+
+                if sort_desc:
+                    query = query.order_by(desc(shelf_computed_models()['Picture'].path))
+                else:
+                    query = query.order_by(shelf_computed_models()['Picture'].path)
+
+                return query, joins
+        except:
+            pass
+
+        query, joins = super(ShelfModelView, self)._order_by(query, joins, sort_field, sort_desc)
+        return query, joins
+
+    def scaffold_sortable_columns(self):
+        """
+            Return a dictionary of sortable columns.
+            Key is column name, value is sort column/field.
+        """
+        columns = super(ShelfModelView, self).scaffold_sortable_columns()
+
+        for k, v in self.model.__dict__.items():
+            if hasattr(v, "mapper"):
+                if issubclass(v.mapper.class_, shelf_computed_models()['LocalizedString']):
+                   columns[k] = v
+                if issubclass(v.mapper.class_, shelf_computed_models()['Picture']):
+                   columns[k] = v
+                if issubclass(v.mapper.class_, shelf_computed_models()['RemoteFile']):
+                   columns[k] = v
+
+        return columns
+
     def after_model_change(self, form, model, is_created):
         if is_created:
             flash('{} was successfully created.'.format(model.__class__.__name__))
